==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_ja.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=ja
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_tout_compris' => '仲間さんのメッセージを全て隠す',
	'bouton_tout_compris_explication' => 'すでにSPIPに慣れている方は、仲間さんのメッセージをすべて無視することが出来ますが、そうでない場合には、各メッセージを個別に閉じることもできます。',

	// C
	'c_accueil_bienvenue' => '@nom@ようこそ！',
	'c_accueil_configurer_site' => 'サイト環境を設定する',
	'c_accueil_configurer_site_texte' => '最初に行うことは、サイトを名付けることです。
現在は「@nom@」と呼ばれています。 このページの最上にはサイトの名前が表示され
ます。
それをクリックすると、その名前を変更することができますが、ロゴとスローガンも
追加できます。',
	'c_accueil_publication' => '公開してください！',
	'c_accueil_publication_texte' => 'ページを公開するには、記事を作成する必要があります。出来るように、少なくともセクションを１つ作成する必要があります。「編集」メニューで「セクション」をクリックしてください。',
	'c_accueil_texte' => 'SPIPの管理エリアに入りました。',
	'c_accueil_texte_revenir' => 'このページには、サイトの最近の編集活動が表示されます。お名前の下の上部にある「家」のアイコンをクリックすることで、いつでもこのページに戻ることができます。',
	'c_article_redaction' => '記事は、編集中です。',
	'c_article_redaction_redacteur' => '記事は、編集中です。',
	'c_article_redaction_redacteur_texte' => '記事をサイト管理者や他の編集者に提出するには、左側のフレームで、「編集中」を「確認のため提出する」に変更してください。',
	'c_article_redaction_texte' => 'この記事をサイトに公開するには、そのステータスを変更する必要があります。左側のフレームで、「確認のため提出する」を「オンラインに公開する」に変更してください。',
	'c_articles_creer' => 'どうやって記事を作成しましょうか。',
	'c_articles_creer_texte' => 'サイトにセクションがある場合にのみ、このページから記事を作成することができます。
「編集」メニューからセクションを作成するには、「セクション」をクリックしてください。',
	'c_job' => 'するべき務め…',
	'c_job_texte' => 'このページには、SPIPによって実行される次のメンテナンスタスクが一覧表示されます。これらのタスクは定期的に実行されるか、またはバルクＥメールの送信など、プラグインによって要求された処理が頻繁に行われることがあります。',
	'c_rubrique_publier' => '記事を作成してください。',
	'c_rubrique_publier_texte' => '公開されたコンテンツが少なくとも1つ含まれている場合にのみ、セクションがサイトに表示されます。 たとえば、公開された記事。
だから記事を作成してください。 このページから、このセクションの説明の下に「新規記事を書く」をクリックすると、それを行うことができます。',
	'c_rubriques_creer' => '第一のセクションを作成してください！',
	'c_rubriques_creer_texte' => 'セクションはサイトの基本構造です。 それぞれに記事を作成することができます。
まず、最初のセクションを作成しましょう。',
	'c_sites_creer' => 'サイトを作成またはインポートする方法は？',
	'c_sites_creer_texte' => 'サイト内にセクションがある場合にのみ、このページからサイトを作成またはインポートすることができます。
「編集」メニューから「セクション」を選択して作成できます。',

	// E
	'explication_activer_compagnon' => '仲間さんは、SPIPを制御するために管理エリアの一部のページに解説を追加します。 
それを有効にしますか？',
	'explication_reinitialiser_compagnon' => '既に表示されているメッセージは表示されなくなります。
これからの「仲間さん」のメッセージをリセットしますか。',

	// L
	'label_activer_compagnon' => '「仲間さん」を有効にしますか。',
	'label_reinitialiser_compagnon' => '仲間さんのメッセージをリセットしますか。',

	// O
	'ok' => 'オケー',
	'ok_bien' => 'よかったです！',
	'ok_jai_compris' => '了解しました！',
	'ok_merci' => 'ありがとう！',
	'ok_parfait' => '最高！',

	// R
	'reinitialisation' => 'リセット',
	'reinitialisation_ok' => 'リセットは完全になりました。',
	'reinitialiser' => 'リセットする',
	'reinitialiser_moi' => 'はい、既に読んでいたメッセージだけ。',
	'reinitialiser_tous' => 'はい、どんな著者でも',

	// T
	'titre_compagnon' => '仲間さん',
	'titre_page_configurer_compagnon' => '「仲間さん」を設定する'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_ja.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=ja
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_tout_compris' => '仲間さんのメッセージを全て隠す',
	'bouton_tout_compris_explication' => 'すでにSPIPに慣れている方は、仲間さんのメッセージをすべて無視することが出来ますが、そうでない場合には、各メッセージを個別に閉じることもできます。',

	// C
	'c_accueil_bienvenue' => '@nom@ようこそ！',
	'c_accueil_configurer_site' => 'サイト環境を設定する',
	'c_accueil_configurer_site_texte' => '最初に行うことは、サイトを名付けることです。
現在は「@nom@」と呼ばれています。 このページの最上にはサイトの名前が表示され
ます。
それをクリックすると、その名前を変更することができますが、ロゴとスローガンも
追加できます。',
	'c_accueil_publication' => '公開してください！',
	'c_accueil_publication_texte' => 'ページを公開するには、記事を作成する必要があります。出来るように、少なくともセクションを１つ作成する必要があります。「編集」メニューで「セクション」をクリックしてください。',
	'c_accueil_texte' => 'SPIPの管理エリアに入りました。',
	'c_accueil_texte_revenir' => 'このページには、サイトの最近の編集活動が表示されます。お名前の下の上部にある「家」のアイコンをクリックすることで、いつでもこのページに戻ることができます。',
	'c_article_redaction' => '記事は、編集中です。',
	'c_article_redaction_redacteur' => '記事は、編集中です。',
	'c_article_redaction_redacteur_texte' => '記事をサイト管理者や他の編集者に提出するには、左側のフレームで、「編集中」を「確認のため提出する」に変更してください。',
	'c_article_redaction_texte' => 'この記事をサイトに公開するには、そのステータスを変更する必要があります。左側のフレームで、「確認のため提出する」を「オンラインに公開する」に変更してください。',
	'c_articles_creer' => 'どうやって記事を作成しましょうか。',
	'c_articles_creer_texte' => 'サイトにセクションがある場合にのみ、このページから記事を作成することができます。
「編集」メニューからセクションを作成するには、「セクション」をクリックしてください。',
	'c_job' => 'するべき務め…',
	'c_job_texte' => 'このページには、SPIPによって実行される次のメンテナンスタスクが一覧表示されます。これらのタスクは定期的に実行されるか、またはバルクＥメールの送信など、プラグインによって要求された処理が頻繁に行われることがあります。',
	'c_rubrique_publier' => '記事を作成してください。',
	'c_rubrique_publier_texte' => '公開されたコンテンツが少なくとも1つ含まれている場合にのみ、セクションがサイトに表示されます。 たとえば、公開された記事。
だから記事を作成してください。 このページから、このセクションの説明の下に「新規記事を書く」をクリックすると、それを行うことができます。',
	'c_rubriques_creer' => '第一のセクションを作成してください！',
	'c_rubriques_creer_texte' => 'セクションはサイトの基本構造です。 それぞれに記事を作成することができます。
まず、最初のセクションを作成しましょう。',
	'c_sites_creer' => 'サイトを作成またはインポートする方法は？',
	'c_sites_creer_texte' => 'サイト内にセクションがある場合にのみ、このページからサイトを作成またはインポートすることができます。
「編集」メニューから「セクション」を選択して作成できます。',

	// E
	'explication_activer_compagnon' => '仲間さんは、SPIPを制御するために管理エリアの一部のページに解説を追加します。 
それを有効にしますか？',
	'explication_reinitialiser_compagnon' => '既に表示されているメッセージは表示されなくなります。
これからの「仲間さん」のメッセージをリセットしますか。',

	// L
	'label_activer_compagnon' => '「仲間さん」を有効にしますか。',
	'label_reinitialiser_compagnon' => '仲間さんのメッセージをリセットしますか。',

	// O
	'ok' => 'オケー',
	'ok_bien' => 'よかったです！',
	'ok_jai_compris' => '了解しました！',
	'ok_merci' => 'ありがとう！',
	'ok_parfait' => '最高！',

	// R
	'reinitialisation' => 'リセット',
	'reinitialisation_ok' => 'リセットは完全になりました。',
	'reinitialiser' => 'リセットする',
	'reinitialiser_moi' => 'はい、既に読んでいたメッセージだけ。',
	'reinitialiser_tous' => 'はい、どんな著者でも',

	// T
	'titre_compagnon' => '仲間さん',
	'titre_page_configurer_compagnon' => '「仲間さん」を設定する',
];
